@@ -25,9 +25,13 @@ def build(setup_kwargs: Any) -> None:
                     [
                         "src/zeroconf/_dns.py",
                         "src/zeroconf/_cache.py",
+                        "src/zeroconf/_history.py",
                         "src/zeroconf/_listener.py",
                         "src/zeroconf/_protocol/incoming.py",
                         "src/zeroconf/_protocol/outgoing.py",
+                        "src/zeroconf/_handlers/record_manager.py",
+                        "src/zeroconf/_services/registry.py",
+                        "src/zeroconf/_utils/time.py",
                     ],
                     compiler_directives={"language_level": "3"},  # Python 3
                 ),
