@@ -345,31 +345,27 @@ class ServiceInfo(RecordUpdateListener):
     def _unpack_text_into_properties(self) -> None:
         """Unpacks the text field into properties"""
         text = self.text
-        end = len(text)
-        if end == 0:
+        if not text:
             # Properties should be set atomically
             # in case another thread is reading them
             self._properties = {}
             return
 
-        result: Dict[Union[str, bytes], Optional[Union[str, bytes]]] = {}
         index = 0
-        strs: List[bytes] = []
+        pairs: List[bytes] = []
+        end = len(text)
         while index < end:
             length = text[index]
             index += 1
-            strs.append(text[index : index + length])
+            pairs.append(text[index : index + length])
             index += length
 
-        for s in strs:
-            key, _, value = s.partition(b'=')
-            # Only update non-existent properties
-            if key and key not in result:
-                result[key] = value or None
-
-        # Properties should be set atomically
-        # in case another thread is reading them
-        self._properties = result
+        # Reverse the list so that the first item in the list
+        # is the last item in the text field. This is important
+        # to preserve backwards compatibility where the first
+        # key always wins if the key is seen multiple times.
+        pairs.reverse()
+        self._properties = {key: value or None for key, _, value in (pair.partition(b'=') for pair in pairs)}
 
     def get_name(self) -> str:
         """Name accessor"""
@@ -410,35 +406,17 @@ class ServiceInfo(RecordUpdateListener):
         else:
             self._ipv4_addresses = self._get_ip_addresses_from_cache_lifo(zc, now, _TYPE_A)
 
-    def update_record(self, zc: 'Zeroconf', now: float, record: Optional[DNSRecord]) -> None:
-        """Updates service information from a DNS record.
-
-        This method is deprecated and will be removed in a future version.
-        update_records should be implemented instead.
-
-        This method will be run in the event loop.
-        """
-        if record is not None:
-            self._process_record_threadsafe(zc, record, now)
-
     def async_update_records(self, zc: 'Zeroconf', now: float, records: List[RecordUpdate]) -> None:
         """Updates service information from a DNS record.
 
         This method will be run in the event loop.
         """
         new_records_futures = self._new_records_futures
-        if self._process_records_threadsafe(zc, now, records) and new_records_futures:
-            _resolve_all_futures_to_none(new_records_futures)
-
-    def _process_records_threadsafe(self, zc: 'Zeroconf', now: float, records: List[RecordUpdate]) -> bool:
-        """Thread safe record updating.
-
-        Returns True if new records were added.
-        """
         updated: bool = False
         for record_update in records:
             updated |= self._process_record_threadsafe(zc, record_update.new, now)
-        return updated
+        if updated and new_records_futures:
+            _resolve_all_futures_to_none(new_records_futures)
 
     def _process_record_threadsafe(self, zc: 'Zeroconf', record: DNSRecord, now: float) -> bool:
         """Thread safe record updating.
@@ -449,7 +427,10 @@ class ServiceInfo(RecordUpdateListener):
             return False
 
         record_key = record.key
-        if record_key == self.server_key and type(record) is DNSAddress:
+        record_type = type(record)
+        if record_key == self.server_key and record_type is DNSAddress:
+            if TYPE_CHECKING:
+                assert isinstance(record, DNSAddress)
             try:
                 ip_addr = _cached_ip_addresses(record.address)
             except ValueError as ex:
@@ -457,9 +438,6 @@ class ServiceInfo(RecordUpdateListener):
                 return False
 
             if type(ip_addr) is IPv4Address:
-                if self._ipv4_addresses:
-                    self._set_ipv4_addresses_from_cache(zc, now)
-
                 ipv4_addresses = self._ipv4_addresses
                 if ip_addr not in ipv4_addresses:
                     ipv4_addresses.insert(0, ip_addr)
@@ -470,9 +448,6 @@ class ServiceInfo(RecordUpdateListener):
 
                 return False
 
-            if not self._ipv6_addresses:
-                self._set_ipv6_addresses_from_cache(zc, now)
-
             ipv6_addresses = self._ipv6_addresses
             if ip_addr not in self._ipv6_addresses:
                 ipv6_addresses.insert(0, ip_addr)
@@ -486,15 +461,20 @@ class ServiceInfo(RecordUpdateListener):
         if record_key != self.key:
             return False
 
-        if record.type == _TYPE_TXT and type(record) is DNSText:
+        if record_type is DNSText:
+            if TYPE_CHECKING:
+                assert isinstance(record, DNSText)
             self._set_text(record.text)
             return True
 
-        if record.type == _TYPE_SRV and type(record) is DNSService:
+        if record_type is DNSService:
+            if TYPE_CHECKING:
+                assert isinstance(record, DNSService)
             old_server_key = self.server_key
-            self.name = record.name
+            self._name = record.name
+            self.key = record.key
             self.server = record.server
-            self.server_key = record.server.lower()
+            self.server_key = record.server_key
             self.port = record.port
             self.weight = record.weight
             self.priority = record.priority
@@ -599,7 +579,11 @@ class ServiceInfo(RecordUpdateListener):
         """Get the addresses from the cache."""
         if self.server_key is None:
             return []
-        return cast("List[DNSAddress]", zc.cache.get_all_by_details(self.server_key, _type, _CLASS_IN))
+        if TYPE_CHECKING:
+            records = cast("List[DNSAddress]", zc.cache.get_all_by_details(self.server_key, _type, _CLASS_IN))
+        else:
+            records = zc.cache.get_all_by_details(self.server_key, _type, _CLASS_IN)
+        return records
 
     def set_server_if_missing(self) -> None:
         """Set the server if it is missing.
@@ -608,7 +592,7 @@ class ServiceInfo(RecordUpdateListener):
         """
         if self.server is None:
             self.server = self._name
-            self.server_key = self.server.lower()
+            self.server_key = self.key
 
     def load_from_cache(self, zc: 'Zeroconf', now: Optional[float] = None) -> bool:
         """Populate the service info from the cache.
